==> ikazuchi-0.4.0.tar.bz2: ikazuchi-0.4.0/src/ikazuchi/tests/data/rst/api_call_directive.py <==
# -*- coding: utf-8 -*-

DATA_SET = [
    (
        [u".. seealso::",
         u"",
         u"    Module :mod:`ikazuchi`",
         u"        ikazuchi is a tool",
         u"        to call api.",
         u"        it helps translation.",
         u"",
         u"    :ref:`ikazuchi-samples`",
         u"        ikazuchi has lots of samples.",
         u""],
        u".. seealso::",

        [u".. seealso::",
         "",
         u"    Module <span class=notranslate>:mod:`ikazuchi`</span>",
         u"        ikazuchi is a tool to call api. it helps translation.",
         "",
         u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>",
         u"        ikazuchi has lots of samples.",
         ""]
    ),
    #(
    #    [u".. seealso::",
    #     u"",
    #     u"    :ref:`ikazuchi-samples`",
    #     u"        ikazuchi has lots of samples.",
    #     u"",
    #     u"          - command line use",
    #     u"          - po file use",
    #     u"          - rst file use",
    #     u""],

    #    [u".. seealso::",
    #     u"",
    #     u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>\n",
    #     u"        ikazuchi has lots of samples.\n",
    #     u"",
    #     u"          - command line use\n",
    #     u"          - po file use\n",
    #     u"          - rst file use\n",
    #     u""]
    #),
    #(
    #    [u".. seealso::",
    #     u"",
    #     u"    :ref:`ikazuchi-samples`",
    #     u"        ikazuchi has lots of samples.",
    #     u"",
    #     u"          | command line use",
    #     u"          |   only translate",
    #     u"          |   translate with audio",
    #     u""],

    #    [u".. seealso::",
    #     u"",
    #     u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>\n",
    #     u"        ikazuchi has lots of samples.\n",
    #     u"",
    #     u"          | command line use\n",
    #     u"          |   only translate\n",
    #     u"          |   translate with audio\n",
    #     u""]
    #),
]

==> ikazuchi-0.5.4.tar.bz2: ikazuchi-0.5.4/src/ikazuchi/tests/data/rst/api_call_directive.py <==
# -*- coding: utf-8 -*-

DATA_SET = [
    (
        [u".. seealso::",
         u"",
         u"    Module :mod:`ikazuchi`",
         u"        ikazuchi is a tool",
         u"        to call api.",
         u"        it helps translation.",
         u"",
         u"    :ref:`ikazuchi-samples`",
         u"        ikazuchi has lots of samples.",
         u""],
        u".. seealso::",

        [u".. seealso::",
         "\n",
         u"    Module <span class=notranslate>:mod:`ikazuchi`</span>\n",
         u"        ikazuchi is a tool to call api. it helps translation.\n",
         "\n",
         u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>\n",
         u"        ikazuchi has lots of samples.\n",
         "\n"]
    ),
    #(
    #    [u".. seealso::",
    #     u"",
    #     u"    :ref:`ikazuchi-samples`",
    #     u"        ikazuchi has lots of samples.",
    #     u"",
    #     u"          - command line use",
    #     u"          - po file use",
    #     u"          - rst file use",
    #     u""],

    #    [u".. seealso::",
    #     u"",
    #     u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>\n",
    #     u"        ikazuchi has lots of samples.\n",
    #     u"",
    #     u"          - command line use\n",
    #     u"          - po file use\n",
    #     u"          - rst file use\n",
    #     u""]
    #),
    #(
    #    [u".. seealso::",
    #     u"",
    #     u"    :ref:`ikazuchi-samples`",
    #     u"        ikazuchi has lots of samples.",
    #     u"",
    #     u"          | command line use",
    #     u"          |   only translate",
    #     u"          |   translate with audio",
    #     u""],

    #    [u".. seealso::",
    #     u"",
    #     u"    <span class=notranslate>:ref:`ikazuchi-samples`</span>\n",
    #     u"        ikazuchi has lots of samples.\n",
    #     u"",
    #     u"          | command line use\n",
    #     u"          |   only translate\n",
    #     u"          |   translate with audio\n",
    #     u""]
    #),
]
